CxIconButton class

Icon Button Component. The Icon is too simple that gives it click event. The Icon has more properties. It includes icon, size, color, hoverColor, focusColor, padding, bgColor.

{@tool snippet}

CxIconButton(
 icon: Icons.heart,
 size: 24,
 bgColor: Colors.pink,
 color: Colors.white,
)

{@end-tool}

Inheritance

Constructors

CxIconButton({Key? key, IconData? icon, void click()?, double? size, Color? color, Color? hoverColor, Color? focusColor, Color? clickColor, double? padding, Color? bgColor})
const

Properties

bgColor → Color?
the background color of the icon.
final
click → void Function()?
icons's click event.
final
clickColor → Color?
color of the click state for icon. Default is Colors.black87.
final
color → Color?
color of the icon. Default is Colors.black.
final
focusColor → Color?
color of the focus state for icon. Default is Colors.black.withAlpha(100).
final
hashCode → int
The hash code for this object.
no setterinherited
hoverColor → Color?
color of the hover state for icon. Default is Colors.black.withAlpha(200).
final
icon → IconData?
icon is IconData object. You should use Icons or other IconData libraries.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → double?
icon's margin space. Default is 6;
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
it sets size of the icon. Default is 16.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CxIconButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited