CxImageCard class
Image Card Component
The focus of the image card is the img address. address is local or network.
Additional properties are title, subtitle, topRight, topLeft, bottomRight, bottomLeft, cornerHeight or imgFix.
The topRight, topLeft, bottomRight and bottomLeft are in the Stack layout. Their type is Widget.
the example below is that how to use it.
{@tool snippet}
CxImageCard(
title: "Movie Name",
subtitle: "a good movie",
img: "https://example.com/images/example.jpg",
imgIsNet: true,
)
{@end-tool}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CxImageCard
Constructors
Properties
-
bottomLeft
→ List<
Widget> ? -
bottom left widget of the image card.
final
-
bottomRight
→ List<
Widget> ? -
bottom right widget of the image card.
final
- cornerHeight → double?
-
the height of the four corners of image card. Default is
20.final - hashCode → int
-
The hash code for this object.
no setterinherited
- img → String?
-
url of the image.
final
- imgFix → BoxFit?
-
Image display mode. Default is
BoxFit.cover.final - imgIsNet → bool?
-
Is this image address in network form. Default is
false.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
the image card's subtitle.
final
- title → String?
-
the title of the image card.
final
-
topLeft
→ List<
Widget> ? -
top left widget of the image card.
final
-
topRight
→ List<
Widget> ? -
top right widget of the image card.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CxImageCard> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited