CxPlaceGrid class
Place Grid Component.
{@tool snippet}
CxPlaceGrid(
items: [
PlaceGridItem(icon:Icons.home, title: "Home")
],
cols: 1,
space: 10,
height: 60,
)
{@end-tool}
the data of gird item. See PlaceGridItem.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CxPlaceGrid
Constructors
-
CxPlaceGrid({Key? key, List<
PlaceGridItem> ? items, int? cols, double? space, double? height, double? ratio, Color? bgColor}) -
const
Properties
- bgColor → Color?
-
background color of the component. default is
transparent.final - cols → int?
-
show several columns. default is
1.final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
height of the component. default is
80.final -
items
→ List<
PlaceGridItem> ? -
data of the component. It's a List<PlaceGridItem> object.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- ratio → double?
-
aspect ratio of the image. default is
1.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- space → double?
-
the space between each item. default is
8.final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CxPlaceGrid> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited